@@ -8,7 +8,9 @@ sub get {
 	return [
 		{'menu file' => [
 			'item file-new',
-			{'menu file_open  file-open' => [
+			undef ,
+			'menu file_insert_templates',
+			{'menu file_open file-open' => [
 				'item file-open',
 				'item file-open-dir',
 				undef ,
@@ -17,18 +19,8 @@ sub get {
 				'item file-reload',
 				'item file-reload-all',
 			],},
-			{'menu file_close' => [
-				'item file-close-current',
-				'item file-close-other',
-				'item file-close-all',
-				undef ,
-				'item file-close-unsaved',
-				'item file-close-other-unsaved',
-				'item file-close-all-unsaved',
-			],},
-			undef ,
 			'menu file_history',
-			'menu file_insert_templates',
+			undef ,
 			{'menu file_session' => [
 				'item file-session-open',
 				'item file-session-add',
@@ -49,6 +41,16 @@ sub get {
 			'item file-rename',
 			#'item file-print',
 			undef ,
+			{'menu file_close file-close-current' => [
+				'item file-close-current',
+				'item file-close-other',
+				'item file-close-all',
+				undef ,
+				'item file-close-unsaved',
+				'item file-close-other-unsaved',
+				'item file-close-all-unsaved',
+			],},
+			undef ,
 			'item app-exit-unsaved',
 			'item app-exit',
 		],},
@@ -174,6 +176,12 @@ sub get {
 			'item goto-line',
 			'item goto-last-edit',
 			undef ,
+			'item marker-goto-prev',
+			'item marker-goto-next',
+			'item marker-toggle-here',
+			'item marker-del-doc',
+			'item marker-del-all',
+			undef ,
 			{'menu bookmark_goto' => [
 				'item bookmark-goto-1',
 				'item bookmark-goto-2',
@@ -204,11 +212,16 @@ sub get {
 			'item tool-note',
 			'item tool-note-selection',
 			undef ,
+			{'menu tool_output' => [
+				'item tool-output-selection-dec',
+				'item tool-output-selection-hex',
+				undef ,
+				'item tool-output-env',
+				'item tool-output-inc',
+			],},
 			'item tool-interpreter-run-document',
 			'item tool-interpreter-stop-document',
 			undef ,
-			'item tool-output-inc',
-			undef ,
 			'item tool-choose-color',
 		],},
 		{'menu document' => [
