@@ -13,22 +13,22 @@ sub get {
 			'item file-close-current#',
 			'item file-save-all',
 			'item file-save',
-			'',
+			undef,
 			'item edit-changes-undo',
 			'item edit-changes-redo',
-			'',
+			undef,
 			'item edit-cut',
 			'item edit-copy',
 			'item edit-paste',
 			'item edit-replace',
 			'item edit-delete',
-			'',
+			undef,
 			'checkitem view-editpanel-line-wrap',
 			'checkitem view-window-stay-on-top',
-			'',
+			undef,
 			'checkitem view-panel-output',
 			'checkitem view-panel-notepad',
-			'',
+			undef,
 			'item view-dialog-find#',
 			'item view-dialog-config#',
 			'item view-dialog-keymap#',
@@ -36,12 +36,14 @@ sub get {
 		searchbar => [
 			'item view-toolbar-search',
 			'combobox find 180',
-			'item find-mark-all#',
 			'item find-prev',
 			'item find-next',
-			'',
+			undef,
 			'item goto-last-edit',
-			'',
+			undef,
+			'item marker-goto-prev',
+			'item marker-goto-next',
+			undef,
 			'item goto-line',
 			'item view-dialog-find',
 		],
